..
  SPDX-License-Identifier: BSD-3-Clause
  Copyright Contributors to the OpenEXR Project.

CrissyField.exr
###############

:download:`https://raw.githubusercontent.com/AcademySoftwareFoundation/openexr-images/main/LuminanceChroma/CrissyField.exr<https://raw.githubusercontent.com/AcademySoftwareFoundation/openexr-images/main/LuminanceChroma/CrissyField.exr>`

.. image:: https://raw.githubusercontent.com/AcademySoftwareFoundation/openexr-images/main/LuminanceChroma/CrissyField.jpg
   :target: https://raw.githubusercontent.com/AcademySoftwareFoundation/openexr-images/main/LuminanceChroma/CrissyField.exr


The Golden Gate without the Bridge

.. list-table::
   :align: left

   * - screenWindowWidth
     - 1
   * - dataWindow
     - (0 0) - (1217 809)
   * - owner
     - Copyright 2006 Industrial Light & Magic
   * - comments
     - The Golden Gate without the Bridge
   * - screenWindowCenter
     - (0 0)
   * - displayWindow
     - (0 0) - (1217 809)
   * - channels
     - BY, RY, Y
   * - lineOrder
     - increasing y
   * - pixelAspectRatio
     - 1
   * - compression
     - b44
   * - type
     - scanlineimage
